from distutils.core import setup
setup(
    name='gluestring',
    packages=['gluestring'],
    version='0.1',
    license='MIT',
    description='Easy way to create template strings',
    author='Aananya',
    author_email='astream.h@outlook.com',
    url='https://github.com/aananya27/gluestring',
    download_url='https://github.com/aananya27/gluestring/archive/v_01.tar.gz',
    keywords=['template', 'string-formatter', 'util'],
    install_requires=[
        're',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.7'
    ],
)
